# Regression.fit api

Last updated: 2024-11-07

This package (rfit - regression.fit) is for use at The University of Chicago Data Science Institute. There are some useful and convenient functions we use in our python classes. 

One of them is dfapi, which connects to the api.regression.fit endpoint, to load dataframes used in some of our classes.

This version fixs minor issue with Numpy 2.0 changes.
